==> ui-hub-0.0.6.tgz: package/es/_hook/doc/desc.md <==
## Hook

你可以在函数组件中使用这些 Hook.

#### 使用方式

```javascript
// 方式一
// 方式一仅可以在 0.0.5 及之后版本中使用
import {
  useRefState,
  useUpdateEffect,
} from 'ui-hub/lib/_hook';

// 方式二
import useRefState from 'ui-hub/lib/_hook/useRefState';
```

#### Hooks列表

+ useRefState

> useRefState<T>(defaultValue: T): [React.MutableRefObject<T>, (value: T) => void | ((cb: (v: T) => T) => void)]

```javascript
const [valueRef, setValue] = useRefState(initValue);
```

`useRefState` 同 `useState` 类似, 只不过 `useRefState` 的返回数组中的第一项是一个 `React.Ref` 对象.
利用该 Hook, 你可以实时利用 `valueRef.current` 获取最新值, 并使用 `setValue` 触发一次组件更新.

+ useUpdateEffect

> useUpdateEffect(effect: React.EffectCallback, deps?: React.DependencyList): void

```javascript
useUpdateEffect(() => {
  // do sth.
}, []);
useUpdateEffect(() => {
  // do sth.
}, [props.someProp]);
```

`useUpdateEffect` 的使用方式同 `useEffect` 一致, 与 `useEffect` 不同的是, `useUpdateEffect` 仅在第二次起的更新中触发副作用回调.

`useUpdateEffect` 与 `useEffect(() => {}, [])` 完全互补.

`useUpdateEffect` 可以理解为 class 组件中的 `componentDidUpdate` 生命周期.

+ useAppLikePageExit (0.0.6版本起支持)

> useAppLikePageExit(configOrContent: ToastProps | string)

仿客户端退出 App 需要点击2次后退按键的交互场景

该 Hook 接收 ui-hub Toast 组件的配置对象或者是提示的文案.

```javascript
function Demo(props) {
  useAppLikePageExit('真的要退出吗?');
  return (
    <div />
  );
}
```

+ usePageBackListener (0.0.6版本起支持)

> usePageBackListener(callback: (reListen: () => void) => void): React.RefObject<PageBackListener | undefined>

PageBackListener 工具组件的 hook 封装.

```javascript
function Demo(props) {
  const ref = usePageBackListener(() => {
    Modal.confirm({
      content: '真的要退出吗?',
      okText: '残忍拒绝',
      onOk: () => {
        // do something
      }
    });
  });
  return (
    <div>
      <button
        onClick={() => {
          ref.current && ref.current.removeListener();
        }}
      >
        移除事件
      </button>
    </div>
  );
}
```

==> ui-hub-0.0.9.tgz: package/es/_hook/doc/desc.md <==
## Hook

你可以在函数组件中使用这些 Hook.

#### 使用方式

```javascript
// 方式一
// 方式一仅可以在 0.0.5 及之后版本中使用
import {
  useRefState,
  useUpdateEffect,
} from 'ui-hub/es/_hook';

// 方式二
import useRefState from 'ui-hub/es/_hook/useRefState';
```

#### Hooks列表

+ useRefState

> useRefState<T>(defaultValue: T): [React.MutableRefObject<T>, (value: T) => void | ((cb: (v: T) => T) => void)]

```javascript
const [valueRef, setValue] = useRefState(initValue);
```

`useRefState` 同 `useState` 类似, 只不过 `useRefState` 的返回数组中的第一项是一个 `React.Ref` 对象.
利用该 Hook, 你可以实时利用 `valueRef.current` 获取最新值, 并使用 `setValue` 触发一次组件更新.

+ useUpdateEffect

> useUpdateEffect(effect: React.EffectCallback, deps?: React.DependencyList): void

```javascript
useUpdateEffect(() => {
  // do sth.
}, []);
useUpdateEffect(() => {
  // do sth.
}, [props.someProp]);
```

`useUpdateEffect` 的使用方式同 `useEffect` 一致, 与 `useEffect` 不同的是, `useUpdateEffect` 仅在第二次起的更新中触发副作用回调.

`useUpdateEffect` 与 `useEffect(() => {}, [])` 完全互补.

`useUpdateEffect` 可以理解为 class 组件中的 `componentDidUpdate` 生命周期.

+ useAppLikePageExit (0.0.6版本起支持)

> useAppLikePageExit(configOrContent: ToastProps | string)

仿客户端退出 App 需要点击2次后退按键的交互场景

该 Hook 接收 ui-hub Toast 组件的配置对象或者是提示的文案.

```javascript
function Demo(props) {
  useAppLikePageExit('真的要退出吗?');
  return (
    <div />
  );
}
```

+ usePageBackListener (0.0.6版本起支持)

> usePageBackListener(callback: (reListen: () => void) => void): React.RefObject<PageBackListener | undefined>

PageBackListener 工具组件的 hook 封装.

```javascript
function Demo(props) {
  const ref = usePageBackListener(() => {
    Modal.confirm({
      content: '真的要退出吗?',
      okText: '残忍拒绝',
      onOk: () => {
        // do something
      }
    });
  });
  return (
    <div>
      <button
        onClick={() => {
          ref.current && ref.current.removeListener();
        }}
      >
        移除事件
      </button>
    </div>
  );
}
```
